@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2003 CodeFactory AB
  * Copyright (C) 2003 Mikael Hallendal <micke@imendio.com>
@@ -24,9 +24,13 @@
 
 #include <glib.h>
 
-gboolean  dh_parser_read_file (const gchar  *path,
-			       GNode        *book_tree,
-			       GList       **keywords,
-			       GError      **error);
+G_BEGIN_DECLS
+
+gboolean dh_parser_read_file (const gchar  *path,
+                              GNode        *book_tree,
+                              GList       **keywords,
+                              GError      **error);
+
+G_END_DECLS
 
 #endif /* __DH_PARSER_H__ */
